@@ -1,15 +1,15 @@
 #
 # This file is part of Config-Model-OpenSsh
 #
-# This software is Copyright (c) 2011 by Dominique Dumont.
+# This software is Copyright (c) 2012 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Backend::OpenSsh ;
-BEGIN {
-  $Config::Model::Backend::OpenSsh::VERSION = '1.217';
+{
+  $Config::Model::Backend::OpenSsh::VERSION = '1.220';
 }
 
 use Any::Moose ;
@@ -38,6 +38,8 @@ my @dispatch = (
     qr/\w/                     => 'assign',
 );
 
+sub skip_open { 1 ;} # tell AutoRead not to try to open a file
+
 sub read_ssh_file {
     my $self = shift ;
     my %args = @_ ;
@@ -59,7 +61,7 @@ sub read_ssh_file {
 
     $logger->info("loading config file $file");
 
-    my $fh = new IO::File $file, "r"  
+    my $fh = IO::File->new( $file, "r")  
         || die __PACKAGE__," read_ssh_file: can't open $file:$!";
 
     my @lines = $fh->getlines ;
